@@ -71,7 +71,9 @@ class BaseLeague(ABC):
         for player in data:
             # two way map to find playerId's by name
             self.player_map[player['id']] = player['fullName']
-            self.player_map[player['fullName']] = player['id']
+            # if two players have the same fullname use first one for now
+            if player['fullName'] not in self.player_map:
+                self.player_map[player['fullName']] = player['id']
     
     def _get_pro_schedule(self, scoringPeriodId: int = None):
         data = self.espn_request.get_pro_schedule()
